@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "hare-mode" "0.2.0"
+(define-package "hare-mode" "20251002.1915"
   "Hare mode."
   '((emacs "25.1"))
   :url "https://git.sr.ht/~grafov/hare-mode"
